#objdump: -d
#name:    
#source:  opr-ext-18.s


dump.o:     file format elf32-s12z


Disassembly of section .text:

00000000 <.text>:
   0:	85 fc ab cd 	sub d1, 175053
   4:	84 f9 fe ed 	sub d0, 130797