
.*:     file format.*


Disassembly of section destsect:

00008004 <[^>]*>:
    8004:	f7ff fffe 	bl	8004 <dest>

Disassembly of section .text:

001080.. <_start>:
  1080..:	f440 8000 	bne.w	8004 <dest>
