.*: Assembler messages:
.*:9: Error: unsupported relocation
.*:10: Error: unsupported relocation
.*:11: Error: unsupported relocation
.*:12: Error: unsupported relocation
.*:13: Error: unsupported relocation
.*:14: Error: unsupported relocation
.*:15: Error: unsupported relocation
.*:16: Error: unsupported relocation
.*:17: Error: unsupported relocation
.*:18: Error: unsupported relocation
.*:19: Error: unsupported relocation
.*:20: Error: unsupported relocation
.*:21: Error: unsupported relocation
.*:22: Error: unsupported relocation
.*:23: Error: unsupported relocation
