.*: Assembler messages:
.*:2: Warning: negative nop control byte, ignored
.*:4: Warning: \.space, \.nops or \.fill with negative value, ignored
.*:3: Error: invalid single nop size: 20 \(expect within \[0, [0-9]+\]\)
