[^:]*: Assembler messages:
[^:]*:4: Error: selected processor does not support `cdp [^']*' in (ARM|Thumb) mode
[^:]*:5: Error: selected processor does not support `cdpeq [^']*' in (ARM|Thumb) mode
[^:]*:7: Error: selected processor does not support `ldc [^.]*' in (ARM|Thumb) mode
[^:]*:8: Error: selected processor does not support `ldcl [^']*' in (ARM|Thumb) mode
[^:]*:9: Error: selected processor does not support `ldcmi [^']*' in (ARM|Thumb) mode
[^:]*:10: Error: selected processor does not support `ldclpl [^']*' in (ARM|Thumb) mode
[^:]*:11: Error: selected processor does not support `ldc [^']*' in (ARM|Thumb) mode
[^:]*:14: Error: selected processor does not support `stc [^']*' in (ARM|Thumb) mode
[^:]*:15: Error: selected processor does not support `stcl [^']*' in (ARM|Thumb) mode
[^:]*:16: Error: selected processor does not support `stceq [^']*' in (ARM|Thumb) mode
[^:]*:17: Error: selected processor does not support `stccc [^']*' in (ARM|Thumb) mode
[^:]*:18: Error: selected processor does not support `stc [^']*' in (ARM|Thumb) mode
[^:]*:21: Error: selected processor does not support `mrc [^']*' in (ARM|Thumb) mode
[^:]*:22: Error: selected processor does not support `mrcge [^']*' in (ARM|Thumb) mode
[^:]*:24: Error: selected processor does not support `mcr [^']*' in (ARM|Thumb) mode
[^:]*:25: Error: selected processor does not support `mcrlt [^']*' in (ARM|Thumb) mode
[^:]*:28: Error: selected processor does not support `ldc [^']*' in (ARM|Thumb) mode
[^:]*:29: Error: selected processor does not support `stc [^']*' in (ARM|Thumb) mode
[^:]*:30: Error: selected processor does not support `ldcl [^']*' in (ARM|Thumb) mode
[^:]*:31: Error: selected processor does not support `stcl [^']*' in (ARM|Thumb) mode
[^:]*:33: Error: selected processor does not support `ldcl [^']*' in (ARM|Thumb) mode
[^:]*:34: Error: selected processor does not support `stcl [^']*' in (ARM|Thumb) mode
[^:]*:41: Error: selected processor does not support `mrcge [^']*' in (ARM|Thumb) mode
