[^:]*: Assembler messages:
[^:]*:8: Error: registers may not be the same -- `ldr r1,\[r1,#5\]!'
[^:]*:12: Error: ldr to register 15 must be 4-byte aligned -- `ldr r15,\[r15,#5\]'
[^:]*:16: Error: branch must be last instruction in IT block -- `ldrge r15,\[r15,#4\]'
[^:]*:25: Error: branch must be last instruction in IT block -- `ldrge r15,.0x4'
[^:]*:30: Error: ldr to register 15 must be 4-byte aligned -- `ldr r15,.-0xab7'
[^:]*:36: Error: branch must be last instruction in IT block -- `ldrge r15,\[r15,r1\]'
[^:]*:41: Error: r13 not allowed here -- `ldr r1,\[r2,r13\]'
[^:]*:42: Error: r15 not allowed here -- `ldr r2,\[r2,r15\]'
[^:]*:47: Error: r15 not allowed here -- `str r15,\[r1,#10\]'
[^:]*:48: Error: cannot use register index with PC-relative addressing -- `str r1,\[r15,#10\]'
[^:]*:51: Error: registers may not be the same -- `str r1,\[r1,#10\]!'
[^:]*:56: Error: r15 not allowed here -- `str r15,\[r1,r2\]'
[^:]*:57: Error: r13 not allowed here -- `str r1,\[r2,r13\]'
[^:]*:58: Error: r15 not allowed here -- `str r1,\[r2,r15\]'
[^:]*:61: Error: Instruction does not support =N addresses -- `ldrt r0,=0x0'
