.*: Assembler messages:
.*:1: Error: selected processor does not support system register name 'id_aa64zfr0_el1'
.*:2: Error: selected processor does not support system register name 'id_aa64zfr0_el1'
.*:4: Error: selected processor does not support system register name 'zcr_el1'
.*:5: Error: selected processor does not support system register name 'zcr_el1'
.*:6: Error: selected processor does not support system register name 'zcr_el1'
.*:7: Error: selected processor does not support system register name 'zcr_el1'
.*:9: Error: selected processor does not support system register name 'zcr_el12'
.*:10: Error: selected processor does not support system register name 'zcr_el12'
.*:11: Error: selected processor does not support system register name 'zcr_el12'
.*:12: Error: selected processor does not support system register name 'zcr_el12'
.*:14: Error: selected processor does not support system register name 'zcr_el2'
.*:15: Error: selected processor does not support system register name 'zcr_el2'
.*:16: Error: selected processor does not support system register name 'zcr_el2'
.*:17: Error: selected processor does not support system register name 'zcr_el2'
.*:19: Error: selected processor does not support system register name 'zcr_el3'
.*:20: Error: selected processor does not support system register name 'zcr_el3'
.*:21: Error: selected processor does not support system register name 'zcr_el3'
.*:22: Error: selected processor does not support system register name 'zcr_el3'
.*:24: Error: selected processor does not support system register name 'zidr_el1'
.*:25: Error: selected processor does not support system register name 'zidr_el1'
