# Source file used to test the add and addi instructions.
	
foo:
	add.n	r4,r4,r4
	addi.n	r4,r4,1
	addi.n	r4,r4,2
	addi.n	r4,r4,4
	addi.n	r4,r4,8
	addi.n	r4,r4,16
	addi.n	r4,r4,32
	addi.n	r4,r4,64
	addi.n	r4,r4,128
